@@ -6,6 +6,8 @@ from processout.activity import Activity
 from processout.addon import Addon
 from processout.apirequest import APIRequest
 from processout.apiversion import APIVersion
+from processout.applepayalternativemerchantcertificates import ApplePayAlternativeMerchantCertificates
+from processout.alternativemerchantcertificate import AlternativeMerchantCertificate
 from processout.balances import Balances
 from processout.balance import Balance
 from processout.card import Card
